==> apache-geode-1.5.0-src.zip: apache-geode-1.5.0-src/geode-lucene/src/test/java/org/apache/geode/cache/lucene/internal/filesystem/ChunkKeyJUnitTest.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more contributor license
 * agreements. See the NOTICE file distributed with this work for additional information regarding
 * copyright ownership. The ASF licenses this file to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance with the License. You may obtain a
 * copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software distributed under the License
 * is distributed on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express
 * or implied. See the License for the specific language governing permissions and limitations under
 * the License.
 */
package org.apache.geode.cache.lucene.internal.filesystem;

import static org.junit.Assert.*;

import java.util.UUID;

import org.junit.Test;
import org.junit.experimental.categories.Category;

import org.apache.geode.CopyHelper;
import org.apache.geode.cache.lucene.internal.LuceneServiceImpl;
import org.apache.geode.test.junit.categories.UnitTest;

@Category(UnitTest.class)
public class ChunkKeyJUnitTest {

  @Test
  public void testSerialization() {
    LuceneServiceImpl.registerDataSerializables();
    ChunkKey key = new ChunkKey(UUID.randomUUID(), 5);
    ChunkKey copy = CopyHelper.deepCopy(key);

    assertEquals(key, copy);
    assertEquals(key.hashCode(), copy.hashCode());
    assertEquals(key.getFileId(), copy.getFileId());
    assertEquals(key.getChunkId(), copy.getChunkId());
  }

}

==> apache-geode-1.6.0-src.zip: apache-geode-1.6.0-src/geode-lucene/src/test/java/org/apache/geode/cache/lucene/internal/filesystem/ChunkKeyJUnitTest.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more contributor license
 * agreements. See the NOTICE file distributed with this work for additional information regarding
 * copyright ownership. The ASF licenses this file to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance with the License. You may obtain a
 * copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software distributed under the License
 * is distributed on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express
 * or implied. See the License for the specific language governing permissions and limitations under
 * the License.
 */
package org.apache.geode.cache.lucene.internal.filesystem;

import static org.junit.Assert.*;

import java.util.UUID;

import org.junit.Test;
import org.junit.experimental.categories.Category;

import org.apache.geode.CopyHelper;
import org.apache.geode.cache.lucene.internal.LuceneServiceImpl;
import org.apache.geode.test.junit.categories.LuceneTest;
import org.apache.geode.test.junit.categories.UnitTest;

@Category({UnitTest.class, LuceneTest.class})
public class ChunkKeyJUnitTest {

  @Test
  public void testSerialization() {
    LuceneServiceImpl.registerDataSerializables();
    ChunkKey key = new ChunkKey(UUID.randomUUID(), 5);
    ChunkKey copy = CopyHelper.deepCopy(key);

    assertEquals(key, copy);
    assertEquals(key.hashCode(), copy.hashCode());
    assertEquals(key.getFileId(), copy.getFileId());
    assertEquals(key.getChunkId(), copy.getChunkId());
  }

}
